# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.course_content_block import CourseContentBlock

class TestCourseContentBlock(unittest.TestCase):
    """CourseContentBlock unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CourseContentBlock:
        """Test CourseContentBlock
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CourseContentBlock`
        """
        model = CourseContentBlock()
        if include_optional:
            return CourseContentBlock(
                block_type = 'text',
                order = 56,
                is_expanded = True,
                content = public_api_server_connector_v2.models.content.Content(
                    link = '', 
                    file_id = '', 
                    audio_id = '', 
                    payload = '', 
                    btn_url = '', 
                    btn_font = '', 
                    btn_size = null, 
                    btn_text = '', 
                    btn_color = '', 
                    btn_target = null, 
                    btn_position = null, 
                    btn_text_color = '', 
                    pdf_id = '', ),
                id = 56,
                course_id = 56,
                created_at = 56
            )
        else:
            return CourseContentBlock(
                block_type = 'text',
                order = 56,
                is_expanded = True,
                id = 56,
                course_id = 56,
                created_at = 56,
        )
        """

    def testCourseContentBlock(self):
        """Test CourseContentBlock"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
